@@ -1,14 +1,15 @@
 from importlib.metadata import version
 
-from .compai import (apply, compose, const, ffilter, fmap, identity, length,
-                     none_map, swap, tuple_map, tupled)
+from .compai import (apply, compose, const, dict_map, ffilter, fmap, identity,
+                     length, none_map, swap, tuple_map, tupled)
 
-__version__ = version('fp-py')
+__version__ = version('compai')
 
 __all__ = [
     'compose',
     'fmap',
     'none_map',
+    'dict_map',
     'tupled',
     'const',
     'swap',
